Introduction to Projects
========================

This "chapter" is mainly here as a placeholder to contain the projects listed  in the table on the table of contents for this book.  The projects are ordered the same as they are in the table, which is largely the order you would go through them if you were following the table of contents in order.

Many of the projects can be done with or without functions, and that is indicated in the Skills Required section.  Even though functions are in the twelvth chapter some instructors prefer to teach them earlier.  Sections 12.1-12.5 can be done any time after sequences if you like.
